@@ -1,7 +1,7 @@
 package String::Lookup::FlatFile;
 
 # version info
-$VERSION= '0.06';
+$VERSION= '0.07';
 
 # make sure we're strict and verbose as possible
 use strict;
@@ -64,6 +64,9 @@ sub flush {
 sub init {
     my ( $class, $options )= @_;
 
+    # defaults
+    $options->{dir} ||= $ENV{STRING_LOOKUP_FLATFILE_DIR};
+
     # sanity check
     my @errors;
     push @errors, "Must have a 'dir' specified" if !$options->{dir};
@@ -139,7 +142,7 @@ String::Lookup::FlatFile - flush String::Lookup to flat files
  tie my %lookup, 'String::Lookup',
 
    # standard persistent storage parameters
-   storage => 'FlatFile', # store in a flate file
+   storage => 'FlatFile', # store in a flat file
    tag     => $tag,       # name of flat file for this lookup hash
    fork    => 1,          # fork for each flush, default: no
 
@@ -152,7 +155,7 @@ String::Lookup::FlatFile - flush String::Lookup to flat files
 
 =head1 VERSION
 
-This documentation describes version 0.01.
+This documentation describes version 0.07.
 
 =head1 DESCRIPTION
 
